memtable

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Entry

type Entry struct {
	Value   []byte
	Deleted bool
}

type MemTable

type MemTable struct {
	// contains filtered or unexported fields
}

func New

func New() *MemTable

func (*MemTable) ApproximateSize

func (m *MemTable) ApproximateSize() int

func (*MemTable) Clear

func (m *MemTable) Clear()

func (*MemTable) Delete

func (m *MemTable) Delete(key []byte)

delete

func (*MemTable) Export

func (m *MemTable) Export() map[string]Entry

Export returns the contents of the memtable for flushing to disk. Tombstones (deleted entries) are explicitly included so they persist to segments and correctly override older values on disk.

func (*MemTable) Get

func (m *MemTable) Get(key []byte) ([]byte, bool)

get

func (*MemTable) Put

func (m *MemTable) Put(key, value []byte)

put

Jump to