package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: May 26, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type KVRequest struct {
Key string `json:"key"`
Value string `json:"value"`
}
type KVResponse struct {
Key string `json:"key,omitempty"`
Value string `json:"value,omitempty"`
Found bool `json:"found,omitempty"`
Error string `json:"error,omitempty"`
}
Stop gracefully shuts down the HTTP server
Source Files
¶
Click to show internal directories.
Click to hide internal directories.